package
Version:
v0.5.2
Opens a new window with list of versions in this module.
Published: May 11, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Snapshot struct {
SourcePath string `json:"source_path"`
Path string `json:"path"`
SizeBytes int64 `json:"size_bytes"`
CreatedAt time.Time `json:"created_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.